@@ -33,8 +33,10 @@ Inspired by [abersheeran/only-pipe](https://github.com/abersheeran/only-pipe) ,
 >>> func = lambda x: PIPE | range(x) | Map(lambda x:x + 1) | Map(str) | list | END
 >>> func(10)
 ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10']
+```
 
-# Or you may want more easy use.
+Or you may want a more easy use.
+```Python
 >>> range(10) | Filter(lambda x:x<5) | list
 [0, 1, 2, 3, 4]
 
@@ -48,11 +50,12 @@ Inspired by [abersheeran/only-pipe](https://github.com/abersheeran/only-pipe) ,
 ```
 """
 __author__ = 'WEN (github.com/GoodManWEN)'
-__version__ = '0.1.5'
+__version__ = '0.1.7'
 
 from .utils import *
 from .wrapper import *
 from .timer import timeit
+from .io import *
 
 __all__ = (
     'timeit',
@@ -60,5 +63,7 @@ __all__ = (
     'END',
     'Filter',
     'Map',
-    'Reduce'
+    'Reduce',
+    'Read',
+    'Write'
 )
